aboutsummaryrefslogtreecommitdiff
path: root/bfd/aoutx.h
diff options
context:
space:
mode:
authorIan Lance Taylor <ian@airs.com>1994-01-19 04:48:37 +0000
committerIan Lance Taylor <ian@airs.com>1994-01-19 04:48:37 +0000
commit3a5b50f4578a8431db1d65bf051e03ce09f9f445 (patch)
treed0f1a65357e921136a012923a0db7723ee511faa /bfd/aoutx.h
parent77918505b5f096f0c1aa07179d54f2f2626ea864 (diff)
downloadgdb-3a5b50f4578a8431db1d65bf051e03ce09f9f445.zip
gdb-3a5b50f4578a8431db1d65bf051e03ce09f9f445.tar.gz
gdb-3a5b50f4578a8431db1d65bf051e03ce09f9f445.tar.bz2
Resolve warning symbols like indirect symbols.
Diffstat (limited to 'bfd/aoutx.h')
-rw-r--r--bfd/aoutx.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/bfd/aoutx.h b/bfd/aoutx.h
index 1e612f3..a11b778 100644
--- a/bfd/aoutx.h
+++ b/bfd/aoutx.h
@@ -3484,12 +3484,14 @@ aout_link_write_symbols (finfo, input_bfd, symbol_map)
external symbol. */
h = *sym_hash;
- /* If this is an indirect symbol, then change hresolve to
- the base symbol. We also change sym_hash so that the
- relocation routines relocate against the real symbol. */
+ /* If this is an indirect or warning symbol, then change
+ hresolve to the base symbol. We also change *sym_hash so
+ that the relocation routines relocate against the real
+ symbol. */
hresolve = h;
if (h != (struct aout_link_hash_entry *) NULL
- && h->root.type == bfd_link_hash_indirect)
+ && (h->root.type == bfd_link_hash_indirect
+ || h->root.type == bfd_link_hash_warning))
{
hresolve = (struct aout_link_hash_entry *) h->root.u.i.link;
while (hresolve->root.type == bfd_link_hash_indirect)